@@ -3,7 +3,7 @@
 use strict;
 use FindBin;
 use File::Spec::Functions ':ALL';
-use LWP::Simple qw(getstore);
+use HTTP::Tiny;
 use ExtUtils::Command;
 
 chdir(catdir($FindBin::Bin, updir())) or die "Failed to change to the dist root";
@@ -28,17 +28,24 @@ my $version_as_num = sprintf( q{%u%02u%02u%02u}, @version_parts );
 my $version_dotty = join '.', ($version_parts[3] ? @version_parts : @version_parts[0..2]);
 my $is_pre_30704_style = ($version_as_num < 3070400);
 my $version_for_url = $is_pre_30704_style ? $version_dotty : $version_as_num;
+my $year = "";
+if ($version_as_num >= 3080800) {
+  $year = "2015/";
+} elsif ($version_as_num >= 3080300) {
+  $year = "2014/";
+} elsif ($version_as_num >= 3071600) {
+  $year = "2013/";
+}
 
-
-my $url_to_download = q{http://www.sqlite.org/sqlite-}
+my $url_to_download = qq{http://www.sqlite.org/${year}sqlite-}
     . ($is_pre_30704_style ? q{amalgamation} : q{autoconf})
     . qq{-$version_for_url.tar.gz};
 print("downloading $url_to_download\n");
-my $rv = getstore(
+my $rv = HTTP::Tiny->new->mirror(
 	$url_to_download, 
 	"sqlite.tar.gz",
 );
-die "Failed to download" if $rv != 200;
+die "Failed to download" if !$rv->{success};
 print("done\n");
 
 rm_rf('sqlite') || rm_rf("sqlite-$version_dotty") || rm_rf("sqlite-amalgamation-$version_dotty");
